@@ -34,7 +34,7 @@ map <- function(x,y=NULL,col="black",lwd=1,lty=1,sym=TRUE,
     addland()
   }
   results <- list(lon=x$lon,lat=x$lat,map=map,
-                  tim=NULL,date=NULL)
+                  tim=NULL,date=NULL,attributes=x$attributes)
   class(results) <- "map"
 #  attr(results) <- attr(x)
   attr(results,"descr") <- "Mean values"
