@@ -8,7 +8,8 @@ library(clim.pact)
 # x.rng <- c(4,25);  y.rng <- c(58,70)   # The whole country focus
 # x.rng <- c(12,26); y.rng <- c(70,80)   # Svalbard focus
 
-domains <- c("D6","D7","D8","D9")
+#domains <- c("D6","D7","D8","D9","D1","D2","D3,","D4","D5")
+domains <- c("D10","D3")
 
 for (domain in domains) {
   x.domain <- switch(domain,
@@ -20,16 +21,18 @@ for (domain in domains) {
                 "D6"=list(x.rng=c(4,14),y.rng=c(58,64)),
                 "D7"=list(x.rng=c(25,32),y.rng=c(70,75)),
                 "D8"=list(x.rng=c(7,15),y.rng=c(56,62)),
-                "D9"=list(x.rng=c(4,25),y.rng=c(58,70)))
+                "D9"=list(x.rng=c(4,25),y.rng=c(58,70)),
+                "D10"=list(x.rng=c(5,13),y.rng=c(59,62)))
 x.rng <- x.domain$x.rng
 y.rng <- x.domain$y.rng
                                         # Daily values:
 x.1.dm<-retrieve.nc("/data1/era15/ERA-15_t2m.nc",
                     x.rng=x.rng,y.rng=y.rng)
-eof.era.dm <- EOF(x.1.dm,mon=1)
-eof.era.dm <- EOF(x.1.dm,mon=2)
-eof.era.dm <- EOF(x.1.dm,mon=3)
-eof.era.dm <- EOF(x.1.dm,mon=4)
+#eof.era.dm <- EOF(x.1.dm,mon=1)
+#eof.era.dm <- EOF(x.1.dm,mon=2)
+#eof.era.dm <- EOF(x.1.dm,mon=3)
+#eof.era.dm <- EOF(x.1.dm,mon=4)
+eof.era.dm <- EOF(x.1.dm,mon=NULL)
 X.1.dm<-retrieve.nc("/data1/hirham/T2M_198001-199912.nc",
                     x.rng=x.rng,y.rng=y.rng)
 Y.1.dm<-retrieve.nc("/data1/hirham/T2M_203001-204912.nc",
@@ -41,6 +44,7 @@ eof.x.dc <- EOF(xX.1.dm,mon=1)
 eof.x.dc <- EOF(xX.1.dm,mon=2)
 eof.x.dc <- EOF(xX.1.dm,mon=3)
 eof.x.dc <- EOF(xX.1.dm,mon=4)
+eof.x.dc <- EOF(xX.1.dm,mon=NULL)
 
 x.2.dm<-retrieve.nc("/data1/era15/ERA-15_slp.nc",
                     x.rng=x.rng,y.rng=y.rng)
@@ -48,6 +52,7 @@ eof.era.dm <- EOF(x.2.dm,mon=1)
 eof.era.dm <- EOF(x.2.dm,mon=2)
 eof.era.dm <- EOF(x.2.dm,mon=3)
 eof.era.dm <- EOF(x.2.dm,mon=4)
+  
 X.2.dm<-retrieve.nc("/data1/hirham/PSL_198001-199912.nc",
                     x.rng=x.rng,y.rng=y.rng)
 Y.2.dm<-retrieve.nc("/data1/hirham/PSL_203001-204912.nc",
@@ -55,7 +60,12 @@ Y.2.dm<-retrieve.nc("/data1/hirham/PSL_203001-204912.nc",
 Y.2.dm$yy <- Y.2.dm$yy + 50
 xX.2.dm <- catFields(X.2.dm,Y.2.dm,demean=FALSE)
 xX.2.dm <- catFields(x.2.dm,xX.2.dm)
-
+eof.x.dc <- EOF(xX.2.dm,mon=1)
+eof.x.dc <- EOF(xX.2.dm,mon=2)
+eof.x.dc <- EOF(xX.2.dm,mon=3)
+eof.x.dc <- EOF(xX.2.dm,mon=4)
+eof.x.dc <- EOF(xX.2.dm,mon=NULL)
+  
 xX.dm <- mixFields(xX.1.dm,xX.2.dm,mon=c(12,1,2))
 eof.x.dmc <- EOF(xX.dm,mon=1)
 
@@ -68,5 +78,8 @@ eof.x.dmc <- EOF(xX.dm,mon=3)
 xX.dm <- mixFields(xX.1.dm,xX.2.dm,mon=c(9,10,11))
 eof.x.dmc <- EOF(xX.dm,mon=4)
 
+xX.dm <- mixFields(xX.1.dm,xX.2.dm,mon=1:12)
+eof.x.dmc <- EOF(xX.dm,mon=NULL)
+
 rm(xX.dm,x.1.dm,x.2.dm,X.1.dm,X.2.dm,Y.1.dm,Y.2.dm)  
 }
